==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/DeleteVodSourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteVodSourceRequest(
    sourceLocationName: __string,
    vodSourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest = {
    import DeleteVodSourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
      .builder()
      .sourceLocationName(__string.unwrap(sourceLocationName): java.lang.String)
      .vodSourceName(__string.unwrap(vodSourceName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DeleteVodSourceRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteVodSourceRequest.wrap(buildAwsValue())
}
object DeleteVodSourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteVodSourceRequest =
      zio.aws.mediatailor.model
        .DeleteVodSourceRequest(sourceLocationName, vodSourceName)
    def sourceLocationName: __string
    def vodSourceName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
    def getVodSourceName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(vodSourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
  ) extends zio.aws.mediatailor.model.DeleteVodSourceRequest.ReadOnly {
    override val sourceLocationName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.sourceLocationName())
    override val vodSourceName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.vodSourceName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
  ): zio.aws.mediatailor.model.DeleteVodSourceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-mediatailor_3-6.20.58.1-sources.jar: zio/aws/mediatailor/model/DeleteVodSourceRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteVodSourceRequest(
    sourceLocationName: __string,
    vodSourceName: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest = {
    import DeleteVodSourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
      .builder()
      .sourceLocationName(sourceLocationName: java.lang.String)
      .vodSourceName(vodSourceName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.DeleteVodSourceRequest.ReadOnly =
    zio.aws.mediatailor.model.DeleteVodSourceRequest.wrap(buildAwsValue())
}
object DeleteVodSourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.DeleteVodSourceRequest =
      zio.aws.mediatailor.model
        .DeleteVodSourceRequest(sourceLocationName, vodSourceName)
    def sourceLocationName: __string
    def vodSourceName: __string
    def getSourceLocationName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(sourceLocationName)
    def getVodSourceName: ZIO[Any, Nothing, __string] =
      ZIO.succeed(vodSourceName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
  ) extends zio.aws.mediatailor.model.DeleteVodSourceRequest.ReadOnly {
    override val sourceLocationName: __string =
      impl.sourceLocationName(): __string
    override val vodSourceName: __string = impl.vodSourceName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.DeleteVodSourceRequest
  ): zio.aws.mediatailor.model.DeleteVodSourceRequest.ReadOnly = new Wrapper(
    impl
  )
}
